@@ -1,5 +1,7 @@
 package OTRS::OPM::Maker::Command::sopm;
 
+use v5.10;
+
 use strict;
 use warnings;
 
@@ -20,7 +22,7 @@ use OTRS::OPM::Maker -command;
 use OTRS::OPM::Maker::Utils::OTRS3;
 use OTRS::OPM::Maker::Utils::OTRS4;
 
-our $VERSION = 1.36;
+our $VERSION = 1.37;
 
 sub abstract {
     return "build sopm file based on metadata";
@@ -118,6 +120,12 @@ sub execute {
     );
 
     my ($max) = sort{ $b <=> $a }keys %major_versions;
+
+    $json->{product} //= 'OTRS';
+    if ( uc $json->{product} eq 'KIX' ) {
+        $max = 5;
+    }
+
     my $mod   = $utils_versions{$max} || $utils_versions{3};
     my $utils = 'OTRS::OPM::Maker::Utils::' . $mod;
 
@@ -639,7 +647,7 @@ OTRS::OPM::Maker::Command::sopm - Build .sopm file based on metadata
 
 =head1 VERSION
 
-version 1.36
+version 1.37
 
 =head1 DESCRIPTION
 
